@@ -3,7 +3,6 @@ from __future__ import annotations
 import csv
 import hashlib
 import json
-import locale
 import os
 
 from base64 import urlsafe_b64encode
@@ -16,6 +15,7 @@ from poetry.core.masonry.utils.package_include import PackageInclude
 
 from poetry.utils._compat import WINDOWS
 from poetry.utils._compat import decode
+from poetry.utils._compat import getencoding
 from poetry.utils.env import build_environment
 from poetry.utils.helpers import is_dir_writable
 from poetry.utils.pip import pip_install
@@ -125,15 +125,14 @@ class EditableBuilder(Builder):
 
         try:
             pth_file = self._env.site_packages.write_text(
-                pth_file, content, encoding=locale.getpreferredencoding()
+                pth_file, content, encoding=getencoding()
             )
             self._debug(
                 f"  - Adding <c2>{pth_file.name}</c2> to <b>{pth_file.parent}</b> for"
                 f" {self._poetry.file.path.parent}"
             )
             return [pth_file]
-        except OSError:
-            # TODO: Replace with PermissionError
+        except PermissionError:
             self._io.write_error_line(
                 f"  - Failed to create <c2>{pth_file.name}</c2> for"
                 f" {self._poetry.file.path.parent}"
@@ -253,7 +252,8 @@ class EditableBuilder(Builder):
                     "dir_info": {"editable": True},
                     "url": self._poetry.file.path.parent.absolute().as_uri(),
                 }
-            )
+            ),
+            encoding="utf-8",
         )
         added_files.append(direct_url_json)
 
